﻿namespace anbs_cp.Classes;

/// <summary>
///     Конвертер типов на манер Delphi
/// </summary>
public static class TypeConverter
{
    #region Конвертация числа в строку

    /// <summary>
    ///     Преобразование int в string
    /// </summary>
    /// <param name="aInt">Число</param>
    /// <returns>Строка</returns>
    public static string IntToStr (int aInt) => aInt.ToString();

    /// <summary>
    ///     Преобразование uint в string
    /// </summary>
    /// <param name="aInt">Число</param>
    /// <returns>Строка</returns>
    public static string IntToStr (uint aInt) => aInt.ToString();

    /// <summary>
    ///     Преобразование long в string
    /// </summary>
    /// <param name="aInt">Число</param>
    /// <returns>Строка</returns>
    public static string IntToStr (long aInt) => aInt.ToString();

    /// <summary>
    ///     Преобразование ulong в string
    /// </summary>
    /// <param name="aInt">Число</param>
    /// <returns>Строка</returns>
    public static string IntToStr (ulong aInt) => aInt.ToString();

    /// <summary>
    ///     Преобразование byte в string
    /// </summary>
    /// <param name="aInt">Число</param>
    /// <returns>Строка</returns>
    public static string IntToStr (byte aInt) => aInt.ToString();

    #endregion

    #region Конвертация строки в число

    /// <summary>
    ///     Преобразование строки в число
    /// </summary>
    /// <param name="aStr">Строка</param>
    /// <param name="aDefault">Значение по умолчанию (по умолчанию, 0)</param>
    /// <returns>Число</returns>
    public static int StrToInt (string aStr, int aDefault = 0)
    {
        if (!int.TryParse(aStr, out int result))
            result = aDefault;
        return result;
    }

    /// <summary>
    ///     Преобразование строки в число
    /// </summary>
    /// <param name="aStr">Строка</param>
    /// <param name="aDefault">Значение по умолчанию (по умолчанию, 0)</param>
    /// <returns>Число</returns>
    public static uint StrToUInt (string aStr, uint aDefault = 0)
    {
        if (!uint.TryParse(aStr, out uint result))
            result = aDefault;
        return result;
    }

    /// <summary>
    ///     Преобразование строки в число
    /// </summary>
    /// <param name="aStr">Строка</param>
    /// <param name="aDefault">Значение по умолчанию (по умолчанию, 0)</param>
    /// <returns>Число</returns>
    public static long StrToInt64 (string aStr, long aDefault = 0)
    {
        if (!long.TryParse(aStr, out long result))
            result = aDefault;
        return result;
    }

    /// <summary>
    ///     Преобразование строки в число
    /// </summary>
    /// <param name="aStr">Строка</param>
    /// <param name="aDefault">Значение по умолчанию (по умолчанию, 0)</param>
    /// <returns>Число</returns>
    public static ulong StrToUInt64 (string aStr, ulong aDefault = 0)
    {
        if (!ulong.TryParse(aStr, out ulong result))
            result = aDefault;
        return result;
    }

    /// <summary>
    ///     Преобразование строки в число
    /// </summary>
    /// <param name="aStr">Строка</param>
    /// <param name="aDefault">Значение по умолчанию (по умолчанию, 0)</param>
    /// <returns>Число</returns>
    public static byte StrToByte (string aStr, byte aDefault = 0)
    {
        if (!byte.TryParse(aStr, out byte result))
            result = aDefault;
        return result;
    }

    #endregion
}